#!/bin/bash

VERSION=3.20.0

0publish -v solfege.xml \
  --add-version=$VERSION \
  --set-released=today \
  --set-arch=Linux-x86_64 \
  --set-stability=developer \
  --set-main=solfege-$VERSION-Linux-x86_64/bin/solfege \
  --archive-url=http://downloads.sourceforge.net/project/solfege/solfege-stable/3.20.0/0install/solfege-3.20.0-Linux-x86_64.tar.gz


0publish -v solfege.xml \
  --add-version=$VERSION \
  --set-released=today \
  --set-arch=Linux-i386 \
  --set-stability=developer \
  --set-main=solfege-$VERSION-Linux-i386/bin/solfege \
  --archive-url=http://downloads.sourceforge.net/project/solfege/solfege-stable/3.20.0/0install/solfege-3.20.0-Linux-i386.tar.gz

echo "Not complete yet. Must check solfege.xml with 0publish-gui"
